<?php

/*
Plugin Name: WP Realtime Sitemap
Plugin URI: http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-home/
Description: Adds a sitemap to your Wordpress blog that is always up-to-date. Add `[wp-realtime-sitemap show="all"]` to any page or post and the site map will be added there. Use Settings->WP Realtime Sitemap to set options.
Version: 1.4.4
Author: Daniel Tweedy
Author URI: http://www.daniel-tweedy.co.uk/
License: GPL2
*/

/*  Copyright 2010  WP Realtime Sitemap  (email : support@daniel-tweedy.co.uk)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

load_plugin_textdomain('wp-realtime-sitemap', false, dirname(plugin_basename(__FILE__)) . '/language');

function wprs_options_form() {
	// check user has access to change settings for this plugin.
	if (!current_user_can('manage_options')) {
		wp_die( __('You do not have sufficient permissions to access this page.', 'wp-realtime-sitemap') );
	}

	// Check if we have a posted form to deal with.
	if (isset($_POST['info_update'])) {
		// check admin security.
		check_admin_referer('wp-realtime-sitemap');

		// Get current options from the database.
		$options = get_option('plugin_wp_realtime_sitemap_settings');

		// Update current options with options submitted by the form.
		$options['sort_column']		= $_POST['sort_column'];
		$options['sort_order']		= $_POST['sort_order'];
		$options['show_count']		= $_POST['show_count'];
		$options['show_date']		= $_POST['show_date'];
		$options['show_pages']		= $_POST['show_pages'];
		$options['show_posts']		= $_POST['show_posts'];
		$options['show_archives']	= $_POST['show_archives'];
		$options['show_categories']	= $_POST['show_categories'];
		$options['category_tagcloud']	= $_POST['category_tagcloud'];
		$options['show_tags']		= $_POST['show_tags'];
		$options['tags_tagcloud']	= $_POST['tags_tagcloud'];

		// Update settings posted via the form into the database.
		update_option('plugin_wp_realtime_sitemap_settings', $options);

		// Get current options from the database.
		extract(get_option('plugin_wp_realtime_sitemap_settings'));
	}

	// Check if we have a posted form to deal with.
	if (isset($_POST['reset_options'])) {
		// check admin security.
		check_admin_referer('wp-realtime-sitemap');

		// Restore settings back to the defaults.
		update_option('plugin_wp_realtime_sitemap_settings', array(
			'sort_column'		=> 'post_date',
			'sort_order'		=> 'ASC',
			'show_count'		=> 'no',
			'show_date'		=> 'no',
			'show_pages'		=> 'yes',
			'show_posts'		=> 'yes',
			'show_archives'		=> 'yes',
			'show_categories'	=> 'yes',
			'category_tagcloud'	=> 'no',
			'show_tags'		=> 'no',
			'tags_tagcloud'		=> 'no',
		));

		// Get current options from the database.
		extract(get_option('plugin_wp_realtime_sitemap_settings'));
	}

	// Get current options from the database.
	extract(get_option('plugin_wp_realtime_sitemap_settings'));
?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php _e('WP Realtime Sitemap Default Options', 'wp-realtime-sitemap'); ?></h2>

		<form method="post">
			<?php wp_nonce_field('wp-realtime-sitemap'); ?>
			<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="sort_column"><?php _e('Sort column', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="sort_column">
					<option <?php selected('title', $sort_column); ?> value="title"><?php _e('Alphabetically (by title) (Default)', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('menu_order', $sort_column); ?> value="menu_order"><?php _e('Page order', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('date', $sort_column); ?> value="date"><?php _e('Creation time', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('modified', $sort_column); ?> value="modified"><?php _e('Time last modified', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('ID', $sort_column); ?> value="ID"><?php _e('Numeric Page ID', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('author', $sort_column); ?> value="author"><?php _e('Page author', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('name', $sort_column); ?> value="name"><?php _e('Alphabetically (by post slug)', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="sort_order"><?php _e('Sort order', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="sort_order">
					<option <?php selected('ASC', $sort_order); ?> value="ASC"><?php _e('Ascending (Default)', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('DESC', $sort_order); ?> value="DESC"><?php _e('Descending', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_count"><?php _e('Show post count', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_count">
					<option <?php selected('yes', $show_count); ?> value="yes"><?php _e('Yes/On', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('no', $show_count); ?> value="no"><?php _e('No/Off (Default)', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_date"><?php _e('Show date', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_date">
					<option <?php selected('yes', $show_date); ?> value="yes"><?php _e('Yes/On', 'wp-realtime-sitemap'); ?></option>
					<option <?php selected('no', $show_date); ?> value="no"><?php _e('No/Off (Default)', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_pages"><?php _e('Show pages', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_pages">
					<option value="yes" <?php selected('yes', $show_pages); ?>><?php _e('Yes/On (Default)', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $show_pages); ?>><?php _e('No/Off', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_posts"><?php _e('Show posts', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_posts">
					<option value="yes" <?php selected('yes', $show_posts); ?>><?php _e('Yes/On (Default)', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $show_posts); ?>><?php _e('No/Off', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_archives"><?php _e('Show archives', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_archives">
					<option value="yes" <?php selected('yes', $show_archives); ?>><?php _e('Yes/On (Default)', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $show_archives); ?>><?php _e('No/Off', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_categories"><?php _e('Show categories', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_categories">
					<option value="yes" <?php selected('yes', $show_categories); ?>><?php _e('Yes/On (Default)', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $show_categories); ?>><?php _e('No/Off', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="category_tagcloud"><?php _e('Show categories as a tag cloud', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="category_tagcloud">
					<option value="yes" <?php selected('yes', $category_tagcloud); ?>><?php _e('Yes/On', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $category_tagcloud); ?>><?php _e('No/Off (Default)', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="show_tags"><?php _e('Show tags', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="show_tags">
					<option value="yes" <?php selected('yes', $show_tags); ?>><?php _e('Yes/On (Default)', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $show_tags); ?>><?php _e('No/Off', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="tags_tagcloud"><?php _e('Show tags as a tag cloud', 'wp-realtime-sitemap'); ?></label></th>
				<td><select name="tags_tagcloud">
					<option value="yes" <?php selected('yes', $tags_tagcloud); ?>><?php _e('Yes/On', 'wp-realtime-sitemap'); ?></option>
					<option value="no" <?php selected('no', $tags_tagcloud); ?>><?php _e('No/Off (Default)', 'wp-realtime-sitemap'); ?></option>
				</select></td>
			</tr>
			</table>

			<div class="submit">
				<input type="submit" name="info_update" value="<?php _e('Update Options', 'wp-realtime-sitemap'); ?>" />
			</div>
		</form>

		<form method="post">
			<?php wp_nonce_field('wp-realtime-sitemap'); ?>

			<div class="submit">
				<input type="submit" name="reset_options" value="<?php _e('Restore Defaults', 'wp-realtime-sitemap'); ?>" />
			</div>
		</form>
	</div><?php
} // End wprs_options_form()

// To replace the shortcode with the actual sitemap.
function wp_realtime_sitemap($atts, $content=null, $code='') {
	global $wpdb, $table_prefix;

	// Only perform plugin functionality if post/page text has the shortcode in the page.
	if (preg_match('|wp-realtime-sitemap|', $code)) {

		// Get option values from the database.
		$all_options	= get_option('plugin_wp_realtime_sitemap_settings');

		extract(shortcode_atts(array(
			'show'		=> 'all',
			'sort_column'	=> $all_options['sort_column'],
			'sort_order'	=> $all_options['sort_order'],
			'show_count'	=> $all_options['show_count'],
			'show_date'	=> $all_options['show_date'],
		), $atts));

		if ($show == 'categories') {
			$tagcloud	= $all_options['category_tagcloud'];
		} else if ($show == 'tags') {
			$tagcloud	= $all_options['tags_tagcloud'];
		}

		// Pages: Yes/No?
		if ($all_options['show_pages'] != 'no' && $all_options['show_pages'] != 'off') {
			if ($sort_column == 'title' || $sort_column == 'date' || $sort_column == 'modified' || $sort_column == 'author' || $sort_column == 'name')
				$page_sort_column = 'post_' . $sort_column;

			$pages = '<h3>'.__('Pages', 'wp-realtime-sitemap').'</h3>';
			$pages .= '<ul>' . wp_list_pages(array('sort_column' => (!isset($page_sort_column)) ? $sort_column : $page_sort_column, 'sort_order' => $sort_order, 'title_li' => '', 'echo' => '0')) . '</ul>';
		}

		// Posts: Yes/No?
		if ($all_options['show_posts'] != 'no' && $all_options['show_posts'] != 'off') {
			$posts = '';

			// Set options for post query
			$post_args = array(
				'orderby'		=> $sort_column,
				'order'			=> $sort_order,
				'posts_per_page'	=> -1
			);

			// The Query
			query_posts($post_args);

			if (have_posts())
				$posts = '<h3>'.__('Posts', 'wp-realtime-sitemap').'</h3><ul>';

			// The Loop
			while (have_posts()) {
				the_post();

				if ($show_date == 'yes')
					$extra = ' <span>' . get_the_date() . '</span>';

				$posts .= '<li><a href="' . get_permalink() . '" title="' . sprintf(esc_attr__('Permalink to %s', 'wp-realtime-sitemap'), the_title_attribute('echo=0')) . '" rel="bookmark">' . get_the_title() . '</a>' . $extra . '</li>';
			}

			if (have_posts())
				$posts .= '</ul>';

			// Reset Query
			wp_reset_query();

		}

		// Archives: Yes/No?
		if ($all_options['show_archives'] != 'no' && $all_options['show_archives'] != 'off') {
			$archives = '<h3>'.__('Archives', 'wp-realtime-sitemap').'</h3>';
			$archives .= '<ul>' . wp_get_archives(array('type' => 'monthly', 'show_post_count' => ($show_count == 'yes') ? true : false, 'echo' => 0)) . '</ul>';
		}

		// Categories: Yes/No?
		if ($all_options['show_categories'] != 'no' && $all_options['show_categories'] != 'off') {
			$categories = '<h3>'.__('Categories', 'wp-realtime-sitemap').'</h3>';

			// Tag Cloud: Yes/No?
			if ($all_options['category_tagcloud'] != 'no' && $all_options['category_tagcloud'] != 'off') {
				$categories .= wp_tag_cloud(array('format' => 'flat', 'separator' => ' ', 'taxonomy' => 'category', 'echo' => '0'));
			} else {
				if ($sort_column != 'ID' || $sort_column != 'name' || $sort_column != 'slug' || $sort_column != 'count' || $sort_column != 'term_group') {
					$categories_sort_column = 'name';
				}

				$categories .= '<ul>' . wp_list_categories(array('orderby' => (!isset($categories_sort_column)) ? $sort_column : $categories_sort_column, 'order' => $sort_order, 'show_count' => ($show_count == 'yes') ? true : false, 'hierarchical' => true, 'title_li' => '', 'echo' => '0', 'taxonomy' => 'category')) . '</ul>';
			}
		}

		// Tags: Yes/No?
		if ($all_options['show_tags'] != 'no' && $all_options['show_tags'] != 'off') {
			$tags = '<h3>'.__('Tags', 'wp-realtime-sitemap').'</h3>';

			// Tag Cloud: Yes/No?
			if ($all_options['tags_tagcloud'] != 'no' && $all_options['tags_tagcloud'] != 'off') {
				$tags .= wp_tag_cloud(array('format' => 'flat', 'separator' => ' ', 'echo' => '0'));
			} else {
				if ($sort_column != 'ID' || $sort_column != 'name' || $sort_column != 'slug' || $sort_column != 'count' || $sort_column != 'term_group') {
					$tags_sort_column = 'name';
				}

				$tags .= '<ul>' . wp_list_categories(array('orderby' => (!isset($tags_sort_column)) ? $sort_column : $tags_sort_column, 'order' => $sort_order, 'show_count' => ($show_count == 'yes') ? true : false, 'hierarchical' => true, 'title_li' => '', 'echo' => '0', 'taxonomy' => 'post_tag')) . '</ul>';
			}
		}

		if ($show == 'pages') {
			return $pages;
		}

		if ($show == 'posts') {
			return $posts;
		}

		if ($show == 'archives') {
			return $archives;
		}

		if ($show == 'categories') {
			return $categories;
		}

		if ($show == 'tags') {
			return $tags;
		}

		if ($show == 'all') {
			return $pages . $posts . $archives . $categories . $tags;
		}
	}
} // End wp_realtime_sitemap()

add_shortcode('wp-realtime-sitemap', 'wp_realtime_sitemap');

function wprs_plugin_action_links($links, $file) {
	$plugin_file = basename(__FILE__);
	if (basename($file) == $plugin_file) {
		$settings_link = '<a href="options-general.php?page='.$plugin_file.'">'.__('Settings', 'wp-realtime-sitemap').'</a>';
		array_unshift($links, $settings_link);
	}
	return $links;
}
add_filter('plugin_action_links', 'wprs_plugin_action_links', 10, 2);

function wprs_plugin_row_meta($links, $file) {
	$plugin_file = basename(__FILE__);
	if (basename($file) == $plugin_file) {
		$faq_link = '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-faq">'.__('FAQ', 'wp-realtime-sitemap').'</a>';
		array_unshift($links, $faq_link);
		$support_link = '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-support">'.__('Support', 'wp-realtime-sitemap').'</a>';
		array_unshift($links, $support_link);
		$settings_link = '<a href="options-general.php?page='.$plugin_file.'">'.__('Settings', 'wp-realtime-sitemap').'</a>';
		array_unshift($links, $settings_link);
		$donate_link = '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-donate">'.__('Donate', 'wp-realtime-sitemap').'</a>';
		array_unshift($links, $donate_link);
	}
	return $links;
}
add_filter('plugin_row_meta', 'wprs_plugin_row_meta', 10, 2);

function wprs_admin_menu() {
	if (function_exists('add_options_page')) {
		add_options_page(
			__('WP Realtime Sitemap Options', 'wp-realtime-sitemap')
			, __('WP Realtime Sitemap', 'wp-realtime-sitemap')
			, 10
			, basename(__FILE__)
			, 'wprs_options_form'
		);
	}
}
add_action('admin_menu', 'wprs_admin_menu');

function wprs_admin_init() {
	$orderby = get_option('wp_realtime_sitemap_orderby');

	if ($orderby == 'datedesc' || $orderby == 'dateasc')
		$sort_column = 'post_date';

	if ($orderby == 'alphadesc' || $orderby == 'alphaasc')
		$sort_column = 'post_title';

	if ($orderby == 'datedesc' || $orderby == 'alphadesc')
		$sort_order = 'DESC';

	if ($orderby == 'dateasc' || $orderby == 'alphaasc')
		$sort_order = 'ASC';

	// show_pages
	if (get_option('wp_realtime_sitemap_showpages') !== false) {
		$show_pages = get_option('wp_realtime_sitemap_showpages');
	} else if (get_option('wp_realtime_sitemap_pages') !== false) {
		$show_pages = get_option('wp_realtime_sitemap_pages');
	}

	// show_posts
	if (get_option('wp_realtime_sitemap_showposts') !== false) {
		$show_posts = get_option('wp_realtime_sitemap_showposts');
	} else if (get_option('wp_realtime_sitemap_posts') !== false) {
		$show_posts = get_option('wp_realtime_sitemap_posts');
	}

	// show_archives
	if (get_option('wp_realtime_sitemap_showarchives') !== false) {
		$show_archives = get_option('wp_realtime_sitemap_showarchives');
	} else if (get_option('wp_realtime_sitemap_archives') !== false) {
		$show_archives = get_option('wp_realtime_sitemap_archives');
	}

	// show_categories
	if (get_option('wp_realtime_sitemap_showcategories') !== false) {
		$show_categories = get_option('wp_realtime_sitemap_showcategories');
	} else if (get_option('wp_realtime_sitemap_categories') !== false) {
		$show_categories = get_option('wp_realtime_sitemap_categories');
	}

	// category_tagcloud
	if (get_option('wp_realtime_sitemap_showcategoriesastc') !== false) {
		$category_tagcloud = get_option('wp_realtime_sitemap_showcategoriesastc');
	}

	// show_tags
	if (get_option('wp_realtime_sitemap_showtags') !== false) {
		$show_tags = get_option('wp_realtime_sitemap_showtags');
	} else if (get_option('wp_realtime_sitemap_tags') !== false) {
		$show_tags = get_option('wp_realtime_sitemap_tags');
	}

	// tags_tagcloud
	if (get_option('wp_realtime_sitemap_showtagsastc') !== false) {
		$tags_tagcloud = get_option('wp_realtime_sitemap_showtagsastc');
	}

	if (get_option('plugin_wp_realtime_sitemap_settings') === false) {
		// Add default options if first time running - http://striderweb.com/nerdaphernalia/2008/07/consolidate-options-with-arrays/
		add_option('plugin_wp_realtime_sitemap_settings', array(
			'sort_column'		=> (!isset($sort_column))	? 'post_date' : $sort_column,
			'sort_order'		=> (!isset($sort_order))	? 'ASC' : $sort_order,
			'show_count'		=> 'no',
			'show_date'		=> 'no',
			'show_pages'		=> (!isset($show_pages))	? 'yes' : $show_pages,
			'show_posts'		=> (!isset($show_posts))	? 'yes' : $show_posts,
			'show_archives'		=> (!isset($show_archives))	? 'yes' : $show_archives,
			'show_categories'	=> (!isset($show_categories))	? 'yes' : $show_categories,
			'category_tagcloud'	=> (!isset($category_tagcloud))	? 'no' : $category_tagcloud,
			'show_tags'		=> (!isset($show_tags))		? 'no' : $show_tags,
			'tags_tagcloud'		=> (!isset($tags_tagcloud))	? 'no' : $tags_tagcloud,
		));
	} else {
		// Add default options if first time running - http://striderweb.com/nerdaphernalia/2008/07/consolidate-options-with-arrays/
		update_option('plugin_wp_realtime_sitemap_settings', array(
			'sort_column'		=> (!isset($sort_column))	? 'post_date' : $sort_column,
			'sort_order'		=> (!isset($sort_order))	? 'ASC' : $sort_order,
			'show_count'		=> 'no',
			'show_date'		=> 'no',
			'show_pages'		=> (!isset($show_pages))	? 'yes' : $show_pages,
			'show_posts'		=> (!isset($show_posts))	? 'yes' : $show_posts,
			'show_archives'		=> (!isset($show_archives))	? 'yes' : $show_archives,
			'show_categories'	=> (!isset($show_categories))	? 'yes' : $show_categories,
			'category_tagcloud'	=> (!isset($category_tagcloud))	? 'no' : $category_tagcloud,
			'show_tags'		=> (!isset($show_tags))		? 'no' : $show_tags,
			'tags_tagcloud'		=> (!isset($tags_tagcloud))	? 'no' : $tags_tagcloud,
		));
	}

	// Delete old unused database entries - v1.0
	delete_option('wp_realtime_sitemap_orderby');
	delete_option('wp_realtime_sitemap_private');
	delete_option('wp_realtime_sitemap_pages');
	delete_option('wp_realtime_sitemap_posts');
	delete_option('wp_realtime_sitemap_tags');
	delete_option('wp_realtime_sitemap_archives');
	delete_option('wp_realtime_sitemap_displayorder');

	// Delete old unused database entries - v1.1
	delete_option('wp_realtime_sitemap_orderby');
	delete_option('wp_realtime_sitemap_showprivate');
	delete_option('wp_realtime_sitemap_showpages');
	delete_option('wp_realtime_sitemap_showposts');
	delete_option('wp_realtime_sitemap_showarchives');
	delete_option('wp_realtime_sitemap_showcategories');
	delete_option('wp_realtime_sitemap_showcategoriesastc');
	delete_option('wp_realtime_sitemap_showtags');
	delete_option('wp_realtime_sitemap_showtagsastc');
	delete_option('wp_realtime_sitemap_displayorder');
}
add_action('admin_init', 'wprs_admin_init');

function wprs_contextual_help( $help, $screen ) {
	if ( $screen == 'settings_page_wp-realtime-sitemap' ) {
		$help .= '<h5>' . __('WP Realtime Sitemap Help', 'wp-realtime-sitemap') . '</h5><div class="metabox-prefs">';
		$help .= '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-install">'.__( 'WP Realtime Sitemap Home Page', 'wp-realtime-sitemap' ).'</a><br/>';
		$help .= '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-faq">'.__( 'WP Realtime Sitemap FAQ', 'wp-realtime-sitemap' ).'</a><br/>';
		$help .= '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-support">'.__( 'WP Realtime Sitemap Support', 'wp-realtime-sitemap' ).'</a><br/>';
		$help .= '<a href="http://www.daniel-tweedy.co.uk/redir/wp-realtime-sitemap-donate">'.__( 'WP Realtime Sitemap Donate', 'wp-realtime-sitemap' ).'</a><br/>';
		$help .= __( 'Please read the plugin information and FAQ, before asking a question.', 'wp-realtime-sitemap' );
		$help .= '</div>';
	}

	return $help;
}
add_filter( 'contextual_help', 'wprs_contextual_help', 10, 2 );

?>